@@ -1,22 +1,23 @@
-var activity = new Activity("desktop")
+var activity = new Activity("folderview")
+activity.name = i18n("Desktop")
 activity.wallpaperPlugin = "image"
 activity.wallpaperMode = "SingleImage"
 activity.currentConfigGroup = Array("Wallpaper", "image")
-activity.writeConfig("wallpaper", "/usr/share/wallpapers/Mint_Maya")
+activity.writeConfig("wallpaper", "/usr/share/wallpapers/Linux_blue_17")
+activity.writeConfig("wallpaperposition", "2")
 
 activity.currentConfigGroup = new Array('ToolBox')
 activity.writeConfig('corner', '1')
 activity.writeConfig('offset', '0')
-	
-folderview = activity.addWidget("folderview")
-folderview.writeConfig("url", "desktop:/")
 
 var screenrect = screenGeometry(0)
 
 var panel = new Panel("panel")
 panel.location = "bottom"
 launcher = panel.addWidget("launcher")
+launcher.writeConfig("ShowAppsByName","true")
 launcher.globalShortcut = "Alt+F1"
+
 panel.addWidget("showdesktop")
 var widget = panel.addWidget("icon")
 widget.writeConfig("Url", "file:///usr/share/applications/kde4/dolphin.desktop")
@@ -28,6 +29,7 @@ if (hasBattery) {
     systray.currentConfigGroup = new Array("Applets", ++i)
     systray.writeConfig("plugin", "battery")
 }
+
 systray.currentConfigGroup = new Array("Applets", ++i)
 systray.writeConfig("plugin", "message-indicator")
 systray.currentConfigGroup = new Array("Applets", ++i)
@@ -37,6 +39,12 @@ systray.writeConfig("plugin", "notifier")
 
 clock = panel.addWidget("digital-clock")
 clock.writeConfig("showDate", "true")
+clock.writeConfig("dateStyle","0")
+clock.writeConfig("plainClockColor", "43,41,38")
+clock.writeConfig("plainClockDrawShadow","true")
+clock.writeConfig("showSeconds","false")
+clock.writeConfig("showTimeZone","false")
+clock.writeConfig("useCustomColor", "true")
 
 // icons change.
 for (var i = 0; i < panelIds.length; ++i) {                                           
